@@ -1,11 +1,11 @@
-#   -*- coding: utf-8 -*-
-#  SPDX-License-Identifier: MPL-2.0
-#  Copyright 2020-2021 John Mille <john@compose-x.io>
+# SPDX-License-Identifier: MPL-2.0
+# Copyright 2020-2022 John Mille <john@compose-x.io>
+
 import re
 
 NAMESPACE_ARN_RE = re.compile(
-    r"^arn:aws(?:-[a-z]+)?:servicediscovery:(?P<region>[\S]+-[0-9]):(?P<accountid>[\d]{12})"
-    r":namespace/(?P<id>ns-[a-zA-Z0-9]+)$"
+    r"^arn:aws(?:\w+)?:servicediscovery:(?P<region>[a-z\d\-]+-\d):(?P<accountid>\d{12}):"
+    r"namespace/(?P<id>ns-[a-zA-Z\d]+)$"
 )
 
 
